qqnorm.rma.mv <- function(y, ...) {

   mstyle <- .get.mstyle()

   .chkclass(class(y), must="rma.mv", notav="rma.mv")

}
